cumulusci.utils.xml package
===========================

.. automodule:: cumulusci.utils.xml
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

cumulusci.utils.xml.metadata\_tree module
-----------------------------------------

.. automodule:: cumulusci.utils.xml.metadata_tree
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.utils.xml.salesforce\_encoding module
-----------------------------------------------

.. automodule:: cumulusci.utils.xml.salesforce_encoding
   :members:
   :undoc-members:
   :show-inheritance:

